==> zio-aws-elasticache_3-5.19.33.1-sources.jar: zio/aws/elasticache/model/ReplicationGroupPendingModifiedValues.scala <==
package zio.aws.elasticache.model
import zio.aws.elasticache.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ReplicationGroupPendingModifiedValues(
    primaryClusterId: Optional[String] = Optional.Absent,
    automaticFailoverStatus: Optional[
      zio.aws.elasticache.model.PendingAutomaticFailoverStatus
    ] = Optional.Absent,
    resharding: Optional[zio.aws.elasticache.model.ReshardingStatus] =
      Optional.Absent,
    authTokenStatus: Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      Optional.Absent,
    userGroups: Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus] =
      Optional.Absent,
    logDeliveryConfigurations: Optional[
      Iterable[zio.aws.elasticache.model.PendingLogDeliveryConfiguration]
    ] = Optional.Absent,
    transitEncryptionEnabled: Optional[BooleanOptional] = Optional.Absent,
    transitEncryptionMode: Optional[
      zio.aws.elasticache.model.TransitEncryptionMode
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues = {
    import ReplicationGroupPendingModifiedValues.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
      .builder()
      .optionallyWith(primaryClusterId.map(value => value: java.lang.String))(
        _.primaryClusterId
      )
      .optionallyWith(automaticFailoverStatus.map(value => value.unwrap))(
        _.automaticFailoverStatus
      )
      .optionallyWith(resharding.map(value => value.buildAwsValue()))(
        _.resharding
      )
      .optionallyWith(authTokenStatus.map(value => value.unwrap))(
        _.authTokenStatus
      )
      .optionallyWith(userGroups.map(value => value.buildAwsValue()))(
        _.userGroups
      )
      .optionallyWith(
        logDeliveryConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.logDeliveryConfigurations)
      .optionallyWith(
        transitEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.transitEncryptionEnabled)
      .optionallyWith(transitEncryptionMode.map(value => value.unwrap))(
        _.transitEncryptionMode
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly =
    zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues
      .wrap(buildAwsValue())
}
object ReplicationGroupPendingModifiedValues {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues =
      zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues(
        primaryClusterId.map(value => value),
        automaticFailoverStatus.map(value => value),
        resharding.map(value => value.asEditable),
        authTokenStatus.map(value => value),
        userGroups.map(value => value.asEditable),
        logDeliveryConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        transitEncryptionEnabled.map(value => value),
        transitEncryptionMode.map(value => value)
      )
    def primaryClusterId: Optional[String]
    def automaticFailoverStatus
        : Optional[zio.aws.elasticache.model.PendingAutomaticFailoverStatus]
    def resharding
        : Optional[zio.aws.elasticache.model.ReshardingStatus.ReadOnly]
    def authTokenStatus
        : Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus]
    def userGroups
        : Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly]
    def logDeliveryConfigurations: Optional[
      List[zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly]
    ]
    def transitEncryptionEnabled: Optional[BooleanOptional]
    def transitEncryptionMode
        : Optional[zio.aws.elasticache.model.TransitEncryptionMode]
    def getPrimaryClusterId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("primaryClusterId", primaryClusterId)
    def getAutomaticFailoverStatus: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.PendingAutomaticFailoverStatus
    ] = AwsError.unwrapOptionField(
      "automaticFailoverStatus",
      automaticFailoverStatus
    )
    def getResharding: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.ReshardingStatus.ReadOnly
    ] = AwsError.unwrapOptionField("resharding", resharding)
    def getAuthTokenStatus
        : ZIO[Any, AwsError, zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      AwsError.unwrapOptionField("authTokenStatus", authTokenStatus)
    def getUserGroups: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly
    ] = AwsError.unwrapOptionField("userGroups", userGroups)
    def getLogDeliveryConfigurations: ZIO[Any, AwsError, List[
      zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "logDeliveryConfigurations",
      logDeliveryConfigurations
    )
    def getTransitEncryptionEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField(
        "transitEncryptionEnabled",
        transitEncryptionEnabled
      )
    def getTransitEncryptionMode
        : ZIO[Any, AwsError, zio.aws.elasticache.model.TransitEncryptionMode] =
      AwsError.unwrapOptionField("transitEncryptionMode", transitEncryptionMode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ) extends zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly {
    override val primaryClusterId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.primaryClusterId())
      .map(value => value: String)
    override val automaticFailoverStatus
        : Optional[zio.aws.elasticache.model.PendingAutomaticFailoverStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.automaticFailoverStatus())
        .map(value =>
          zio.aws.elasticache.model.PendingAutomaticFailoverStatus.wrap(value)
        )
    override val resharding
        : Optional[zio.aws.elasticache.model.ReshardingStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resharding())
        .map(value => zio.aws.elasticache.model.ReshardingStatus.wrap(value))
    override val authTokenStatus
        : Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.authTokenStatus())
        .map(value =>
          zio.aws.elasticache.model.AuthTokenUpdateStatus.wrap(value)
        )
    override val userGroups
        : Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userGroups())
        .map(value =>
          zio.aws.elasticache.model.UserGroupsUpdateStatus.wrap(value)
        )
    override val logDeliveryConfigurations: Optional[
      List[zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.logDeliveryConfigurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticache.model.PendingLogDeliveryConfiguration.wrap(item)
        }.toList
      )
    override val transitEncryptionEnabled: Optional[BooleanOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitEncryptionEnabled())
        .map(value => value: BooleanOptional)
    override val transitEncryptionMode
        : Optional[zio.aws.elasticache.model.TransitEncryptionMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitEncryptionMode())
        .map(value =>
          zio.aws.elasticache.model.TransitEncryptionMode.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ): zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticache_3-7.21.15.4-sources.jar: zio/aws/elasticache/model/ReplicationGroupPendingModifiedValues.scala <==
package zio.aws.elasticache.model
import zio.aws.elasticache.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ReplicationGroupPendingModifiedValues(
    primaryClusterId: Optional[String] = Optional.Absent,
    automaticFailoverStatus: Optional[
      zio.aws.elasticache.model.PendingAutomaticFailoverStatus
    ] = Optional.Absent,
    resharding: Optional[zio.aws.elasticache.model.ReshardingStatus] =
      Optional.Absent,
    authTokenStatus: Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      Optional.Absent,
    userGroups: Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus] =
      Optional.Absent,
    logDeliveryConfigurations: Optional[
      Iterable[zio.aws.elasticache.model.PendingLogDeliveryConfiguration]
    ] = Optional.Absent,
    transitEncryptionEnabled: Optional[BooleanOptional] = Optional.Absent,
    transitEncryptionMode: Optional[
      zio.aws.elasticache.model.TransitEncryptionMode
    ] = Optional.Absent,
    clusterMode: Optional[zio.aws.elasticache.model.ClusterMode] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues = {
    import ReplicationGroupPendingModifiedValues.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
      .builder()
      .optionallyWith(primaryClusterId.map(value => value: java.lang.String))(
        _.primaryClusterId
      )
      .optionallyWith(automaticFailoverStatus.map(value => value.unwrap))(
        _.automaticFailoverStatus
      )
      .optionallyWith(resharding.map(value => value.buildAwsValue()))(
        _.resharding
      )
      .optionallyWith(authTokenStatus.map(value => value.unwrap))(
        _.authTokenStatus
      )
      .optionallyWith(userGroups.map(value => value.buildAwsValue()))(
        _.userGroups
      )
      .optionallyWith(
        logDeliveryConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.logDeliveryConfigurations)
      .optionallyWith(
        transitEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.transitEncryptionEnabled)
      .optionallyWith(transitEncryptionMode.map(value => value.unwrap))(
        _.transitEncryptionMode
      )
      .optionallyWith(clusterMode.map(value => value.unwrap))(_.clusterMode)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly =
    zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues
      .wrap(buildAwsValue())
}
object ReplicationGroupPendingModifiedValues {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues =
      zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues(
        primaryClusterId.map(value => value),
        automaticFailoverStatus.map(value => value),
        resharding.map(value => value.asEditable),
        authTokenStatus.map(value => value),
        userGroups.map(value => value.asEditable),
        logDeliveryConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        transitEncryptionEnabled.map(value => value),
        transitEncryptionMode.map(value => value),
        clusterMode.map(value => value)
      )
    def primaryClusterId: Optional[String]
    def automaticFailoverStatus
        : Optional[zio.aws.elasticache.model.PendingAutomaticFailoverStatus]
    def resharding
        : Optional[zio.aws.elasticache.model.ReshardingStatus.ReadOnly]
    def authTokenStatus
        : Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus]
    def userGroups
        : Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly]
    def logDeliveryConfigurations: Optional[
      List[zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly]
    ]
    def transitEncryptionEnabled: Optional[BooleanOptional]
    def transitEncryptionMode
        : Optional[zio.aws.elasticache.model.TransitEncryptionMode]
    def clusterMode: Optional[zio.aws.elasticache.model.ClusterMode]
    def getPrimaryClusterId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("primaryClusterId", primaryClusterId)
    def getAutomaticFailoverStatus: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.PendingAutomaticFailoverStatus
    ] = AwsError.unwrapOptionField(
      "automaticFailoverStatus",
      automaticFailoverStatus
    )
    def getResharding: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.ReshardingStatus.ReadOnly
    ] = AwsError.unwrapOptionField("resharding", resharding)
    def getAuthTokenStatus
        : ZIO[Any, AwsError, zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      AwsError.unwrapOptionField("authTokenStatus", authTokenStatus)
    def getUserGroups: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly
    ] = AwsError.unwrapOptionField("userGroups", userGroups)
    def getLogDeliveryConfigurations: ZIO[Any, AwsError, List[
      zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "logDeliveryConfigurations",
      logDeliveryConfigurations
    )
    def getTransitEncryptionEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField(
        "transitEncryptionEnabled",
        transitEncryptionEnabled
      )
    def getTransitEncryptionMode
        : ZIO[Any, AwsError, zio.aws.elasticache.model.TransitEncryptionMode] =
      AwsError.unwrapOptionField("transitEncryptionMode", transitEncryptionMode)
    def getClusterMode
        : ZIO[Any, AwsError, zio.aws.elasticache.model.ClusterMode] =
      AwsError.unwrapOptionField("clusterMode", clusterMode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ) extends zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly {
    override val primaryClusterId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.primaryClusterId())
      .map(value => value: String)
    override val automaticFailoverStatus
        : Optional[zio.aws.elasticache.model.PendingAutomaticFailoverStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.automaticFailoverStatus())
        .map(value =>
          zio.aws.elasticache.model.PendingAutomaticFailoverStatus.wrap(value)
        )
    override val resharding
        : Optional[zio.aws.elasticache.model.ReshardingStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resharding())
        .map(value => zio.aws.elasticache.model.ReshardingStatus.wrap(value))
    override val authTokenStatus
        : Optional[zio.aws.elasticache.model.AuthTokenUpdateStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.authTokenStatus())
        .map(value =>
          zio.aws.elasticache.model.AuthTokenUpdateStatus.wrap(value)
        )
    override val userGroups
        : Optional[zio.aws.elasticache.model.UserGroupsUpdateStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userGroups())
        .map(value =>
          zio.aws.elasticache.model.UserGroupsUpdateStatus.wrap(value)
        )
    override val logDeliveryConfigurations: Optional[
      List[zio.aws.elasticache.model.PendingLogDeliveryConfiguration.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.logDeliveryConfigurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticache.model.PendingLogDeliveryConfiguration.wrap(item)
        }.toList
      )
    override val transitEncryptionEnabled: Optional[BooleanOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitEncryptionEnabled())
        .map(value => value: BooleanOptional)
    override val transitEncryptionMode
        : Optional[zio.aws.elasticache.model.TransitEncryptionMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitEncryptionMode())
        .map(value =>
          zio.aws.elasticache.model.TransitEncryptionMode.wrap(value)
        )
    override val clusterMode: Optional[zio.aws.elasticache.model.ClusterMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.clusterMode())
        .map(value => zio.aws.elasticache.model.ClusterMode.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.ReplicationGroupPendingModifiedValues
  ): zio.aws.elasticache.model.ReplicationGroupPendingModifiedValues.ReadOnly =
    new Wrapper(impl)
}
